@@ -3,13 +3,19 @@ package Pod::ProjectDocs::CSS;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_003'; # TRIAL VERSION
+our $VERSION = '0.48_004'; # TRIAL VERSION
 
 use Moose;
 extends 'Pod::ProjectDocs::File';
 
 use File::Basename;
 
+has 'default_name' => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'podstyle.css',
+);
+
 has 'data' => (
     is => 'ro',
     default => <<'DATA',
@@ -368,12 +374,6 @@ table.dlsip     {
 DATA
 );
 
-sub BUILD {
-    my $self = shift;
-    $self->default_name('podstyle.css');
-    return;
-}
-
 sub relative_url {
     my($self, $doc) = @_;
     my($name, $path) = fileparse $doc->get_output_path, qw/\.html/;
