@@ -3,7 +3,7 @@ package Pod::ProjectDocs::DocManager;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_003'; # TRIAL VERSION
+our $VERSION = '0.48_004'; # TRIAL VERSION
 
 use Moose;
 use File::Find;
@@ -71,7 +71,7 @@ sub _find_files {
                 $matched = 1 if $content !~ m{^=(head1|head2|item|cut)}ismxg;
 
                 unless ($matched) {
-                    push @{ $self->docs // [] },
+                    push @{ $self->docs },
                       Pod::ProjectDocs::Doc->new(
                         config      => $self->config,
                         origin      => $path,
